@@ -1,9 +1,9 @@
 import db_utils as db
 
 
-def connect(cass_ip, cass_kp):
+def start(cass_ip, cass_kp):
     db.connect(cass_ip, cass_kp)
 
 
-def close():
+def stop():
     db.close()
\ No newline at end of file
