@@ -1,3 +1,4 @@
+from multiprocessing import cpu_count
 from cassandra.cluster import Cluster, NoHostAvailable
 from cassandra.decoder import dict_factory
 
@@ -11,8 +12,9 @@ class CassandraConnection(object):
         self.ip = cass_ip
         self.kp = cass_kp
         try:
-            self.cluster = Cluster(contact_points=self.ip,
-                                   control_connection_timeout=10000.0)
+            #self.cluster = Cluster(contact_points=self.ip, control_connection_timeout=10000.0)
+            self.cluster = Cluster(contact_points=self.ip)
+            #self.session = self.cluster.connect(self.kp)
             self.session = TransactionManager(self)
             self.session.row_factory = dict_factory
         except NoHostAvailable:
@@ -26,17 +28,16 @@ class CassandraConnection(object):
 
 
 class TransactionManager:
-
-    sessions = []
-
+    sessions = [] 
+    
     def __init__(self, connector):
         self.connector = connector
-        num_sessions = 1  # cpu_count() - 1 if cpu_count() > 1 else 1
-        for i in range(num_sessions):
+        for i in range(cpu_count() - 1):
             session = self.connector.cluster.connect(self.connector.kp)
             session.row_factory = dict_factory
             self.sessions.append(session)
         print self.sessions
+    
 
     def execute(self, *args, **kwargs):
         current_session = self.sessions.pop(0)
