@@ -6,7 +6,7 @@ class CassandraTestCase(unittest.TestCase):
 
     def setUp(self, cass_ip, cass_kp):
         if not self.test_setup:
-            c.connect(cass_ip, cass_kp)
+            c.start(cass_ip, cass_kp)
             self.__class__.test_setup = True
 
     def tearDown(self):
